@@ -19,6 +19,7 @@ from .base import UNSET, Items, Plotter, aslist, astuple, jetsam
 from .config import (
     get_execution_pool,
     is_abort,
+    is_debug,
     is_endure_operations,
     is_marshal_tasks,
     is_parallel_tasks,
@@ -43,7 +44,7 @@ def _isDebugLogging():
 
 class AbortedException(Exception):
     """
-    Raised from Network when :func:`abort_run()` is called, and contains the solution ...
+    Raised from Network when :func:`.abort_run()` is called, and contains the solution ...
 
     with any values populated so far.
     """
@@ -180,9 +181,15 @@ class Solution(ChainMap, Plotter):
         # assert next(iter(dag.edges))[0] == next(iter(plan.dag.edges))[0]:
 
     def __repr__(self):
-        # TODO: augment Solution.__repr__() when DEBUG-log enabled.
         items = ", ".join(f"{k!r}: {v!r}" for k, v in self.items())
-        return f"{{{items}}}"
+        if is_debug():
+            return self.debugstr()
+        else:
+            return f"{{{items}}}"
+
+    def debugstr(self):
+        # TODO: augment Solution.__repr__() when DEBUG-log enabled.
+        return f"{type(self).__name__}({dict(self)}, {self.plan})"
 
     def operation_executed(self, op, outputs):
         """
@@ -274,8 +281,8 @@ class Solution(ChainMap, Plotter):
         A "virtual" property to a dictionary with keys the names of values that
         exist more than once, and values, all those values in a list, ordered:
 
-        - before :meth:`finished()`, as computed;
-        - after :meth:`finished()`, in reverse.
+        - before :meth:`finalized()`, as computed;
+        - after :meth:`finalized()`, in reverse.
         """
         maps = self.maps
         dd = defaultdict(list)
@@ -311,6 +318,7 @@ class Solution(ChainMap, Plotter):
 
     def _build_pydot(self, **kws):
         """delegate to network"""
+        kws.setdefault("name", f"solution-x{len(self.plan.net.graph.nodes)}-nodes")
         kws.setdefault("solution", self)
         plotter = self.plan
         return plotter._build_pydot(**kws)
@@ -453,10 +461,10 @@ class ExecutionPlan(
         The parent :class:`Network`
     .. attribute:: needs
 
-        An :class:`iset` with the input names needed to exist in order to produce all `provides`.
+        An :class:`.IndexedSet` with the input names needed to exist in order to produce all `provides`.
     .. attribute:: provides
 
-        An :class:`iset` with the outputs names produces when all `inputs` are given.
+        An :class:`.IndexedSet` with the outputs names produces when all `inputs` are given.
     .. attribute:: dag
 
         The regular (not broken) *pruned* subgraph of net-graph.
@@ -479,6 +487,7 @@ class ExecutionPlan(
             clusters = {n: "after pruning" for n in self.dag.nodes}
         mykws = {
             "graph": self.net.graph,
+            "name": f"plan-x{len(self.net.graph.nodes)}-nodes",
             "steps": self.steps,
             "inputs": self.needs,
             "outputs": self.provides,
@@ -493,10 +502,10 @@ class ExecutionPlan(
         provides = aslist(self.provides, "provides")
         steps = (
             "".join(f"\n  +--{s}" for s in self.steps)
-            if _isDebugLogging()
+            if is_debug()
             else ", ".join(str(getattr(s, "name", s)) for s in self.steps)
         )
-        return f"ExecutionPlan(needs={needs}, provides={provides}, x{len(self.steps)} steps:{steps})"
+        return f"ExecutionPlan(needs={needs}, provides={provides}, x{len(self.steps)} steps: {steps})"
 
     def validate(self, inputs: Items, outputs: Items):
         """
@@ -511,9 +520,9 @@ class ExecutionPlan(
 
                 *Plan needs more inputs...*
 
-            - If `outputs` asked cannot be produced by the :attr:`dag`, with msg:
+            - If net cannot produce asked `outputs`, with msg:
 
-                *Impossible outputs...*
+                *Unreachable outputs...*
 
         """
         if not self.dag:
@@ -535,7 +544,8 @@ class ExecutionPlan(
             )
             if unknown:
                 raise ValueError(
-                    f"Impossible outputs: {list(unknown)}\n for graph: {self}\n  {self}"
+                    f"Unreachable outputs {list(unknown)}\n  for given inputs {list(unknown)}"
+                    f"\n for graph: {self}\n  {self}"
                 )
 
     def _check_if_aborted(self, solution):
@@ -771,9 +781,9 @@ class ExecutionPlan(
 
                 *Plan needs more inputs...*
 
-            - If `outputs` asked cannot be produced by the :attr:`dag`, with msg:
+            - If net cannot produce asked `outputs`, with msg:
 
-                *Impossible outputs...*
+                *Unreachable outputs...*
         """
         try:
             self.validate(named_inputs, outputs)
@@ -899,7 +909,7 @@ class Network(Plotter):
         ops = list(yield_ops(self.graph.nodes))
         steps = (
             [f"\n  +--{s}" for s in self.graph.nodes]
-            if _isDebugLogging()
+            if is_debug()
             else ", ".join(n.name for n in ops)
         )
         return f"Network(x{len(self.graph.nodes)} nodes, x{len(ops)} ops: {''.join(steps)})"
@@ -908,6 +918,7 @@ class Network(Plotter):
         from .plot import build_pydot
 
         kws.setdefault("graph", self.graph)
+        kws.setdefault("name", f"network-x{len(self.graph.nodes)}-nodes")
         kws.setdefault("inputs", self.needs)
         kws.setdefault("outputs", self.provides)
 
@@ -1225,9 +1236,9 @@ class Network(Plotter):
 
                 *Plan needs more inputs...*
 
-            - If `outputs` asked cannot be produced by the :attr:`dag`, with msg:
+            - If net cannot produce asked `outputs`, with msg:
 
-                *Impossible outputs...*
+                *Unreachable outputs...*
         """
         ## Make a stable cache-key.
         #
