@@ -22,16 +22,14 @@ from .base import (
     astuple,
     jetsam,
 )
-from .config import is_reschedule_operations, is_solid_true
+from .config import is_debug, is_reschedule_operations, is_solid_true
 from .modifiers import arg, optional, sideffect, vararg, varargs
 
 log = logging.getLogger(__name__)
 
 
 def _dict_without(kw, *todel):
-    for i in todel:
-        del kw[i]
-    return kw
+    return {k: v for k, v in kw.items() if k not in todel}
 
 
 def as_renames(i, argname):
@@ -193,6 +191,8 @@ class FunctionalOperation(Operation):
             )
 
         ## Overwrite reparsed op-data.
+        if name is None:
+            name = str(fn)
         name = ".".join(str(pop) for pop in ((parents or ()) + (name,)))
         name, needs, real_provides = reparse_operation_data(name, needs, provides)
 
@@ -264,7 +264,7 @@ class FunctionalOperation(Operation):
         Make a clone with the some values replaced.
 
         .. ATTENTION::
-            Using :meth:`namedtuple._replace()` would not pass through cstor,
+            Using :meth:`.namedtuple._replace()` would not pass through cstor,
             so would not get a nested `name` with `parents`, not arguments validation.
         """
         # fn = kw["fn"] if "fn" in kw else self.fn
@@ -299,11 +299,7 @@ class FunctionalOperation(Operation):
             errors.append(
                 f"{ner}. Expected needs{list(varargs_bad)} to be non-str iterables!"
             )
-        inputs = (
-            dict(named_inputs)
-            if log.isEnabledFor(logging.DEBUG)
-            else list(named_inputs)
-        )
+        inputs = dict(named_inputs) if is_debug() else list(named_inputs)
         errors.append(f"+++inputs: {inputs}")
         errors.append(f"+++{self}")
 
@@ -521,8 +517,8 @@ class operation:
     """
     A builder for graph-operations wrapping functions.
 
-    :param function fn:
-        The function used by this operation.  This does not need to be
+    :param fn:
+        The callable underlying this operation.  This does not need to be
         specified when the operation object is instantiated and can instead
         be set via ``__call__`` later.
     :param str name:
@@ -564,11 +560,11 @@ class operation:
         added as-is into NetworkX graph
 
     :return:
-        when called, it returns a :class:`FunctionalOperation`
+        when called, it returns a :class:`.FunctionalOperation`
 
     **Example:**
 
-    This is an example of its use, based on the "builder pattern"::
+    This is an example of its use, based on the "builder pattern":
 
         >>> from graphtik import operation
 
@@ -579,7 +575,7 @@ class operation:
         operation(name='add_op', needs=['a', 'b'], provides=['SUM'], fn='sum')
 
     You may keep calling ``withset()`` till you invoke a final ``__call__()``
-    on the builder;  then you get the actual :class:`.FunctionalOperation` instance::
+    on the builder;  then you get the actual :class:`.FunctionalOperation` instance:
 
         >>> # Create `Operation` and overwrite function at the last moment.
         >>> opb(sum)
@@ -606,7 +602,10 @@ class operation:
         returns_dict=None,
         node_props: Mapping = None,
     ):
-        vars(self).update(_dict_without(locals(), "self"))
+        kw = _dict_without(locals(), "self")
+        vars(self).update(kw)
+        # To check `fn` callable.
+        self.withset(**kw)
 
     def withset(
         self,
@@ -625,6 +624,11 @@ class operation:
     ) -> "operation":
         """See :class:`operation` for arguments here."""
         if fn is not None:
+            if not callable(fn):
+                raise ValueError(
+                    f"`fn` arg must be callable, was {type(fn).__name__}!"
+                    f"\n  did you mean? operation(name={fn}, ..."
+                )
             self.fn = fn
         if name is not None:
             self.name = name
@@ -678,7 +682,7 @@ class operation:
                 return a + b
             operator(name='myadd1', needs=['a', 'b'], provides=['c'])(myadd)
 
-        :param function fn:
+        :param fn:
             The function to be used by this ``operation``.
 
         :return:
