@@ -7,8 +7,11 @@ import io
 import json
 import logging
 import os
+import re
 from typing import Any, Callable, List, Mapping, Tuple, Union
+from urllib.parse import urlencode
 
+import networkx
 import pydot
 
 log = logging.getLogger(__name__)
@@ -98,11 +101,11 @@ def _dot2svg(dot):
                     {element_styles}
                 }}
             </style>
-            <script src="http://ariutta.github.io/svg-pan-zoom/dist/svg-pan-zoom.min.js"></script>
+            <script src="https://ariutta.github.io/svg-pan-zoom/dist/svg-pan-zoom.min.js"></script>
             <script type="text/javascript">
                 var scriptTag = document.scripts[document.scripts.length - 1];
                 var parentTag = scriptTag.parentNode;
-                svg_el = parentTag.querySelector(".svg_container svg");
+                var svg_el = parentTag.querySelector(".svg_container svg");
                 svgPanZoom(svg_el, {pan_zoom_json});
             </script>
             {svg_txt}
@@ -165,8 +168,32 @@ def quote_dot_word(word: Any):
     return word
 
 
+def as_identifier(s):
+    """
+    Convert string into a valid ID, both for html & graphviz.
+
+    It must not rely on Graphviz's HTML-like string,
+    because it would not be a valid HTML-ID.
+
+    - Adapted from https://stackoverflow.com/a/3303361/548792,
+    - HTML rule from https://stackoverflow.com/a/79022/548792
+    - Graphviz rules: https://www.graphviz.org/doc/info/lang.html
+    """
+    s = s.strip()
+    # Remove invalid characters
+    s = re.sub("[^0-9a-zA-Z_]", "_", s)
+    # Remove leading characters until we find a letter
+    # (HTML-IDs cannot start with underscore)
+    s = re.sub("^[^a-zA-Z]+", "", s)
+    if s in pydot.dot_keywords:
+        s = f"{s}_"
+
+    return s
+
+
 def build_pydot(
-    graph,
+    graph: networkx.Graph,
+    name=None,
     steps=None,
     inputs=None,
     outputs=None,
@@ -224,6 +251,8 @@ def build_pydot(
     dot = pydot.Dot(
         graph_type="digraph", label=quote_dot_word(title), fontname="italic"
     )
+    if name:
+        dot.set_name(as_identifier(name))
 
     # draw nodes
     for nx_node in graph.nodes:
@@ -268,7 +297,10 @@ def build_pydot(
                 kw["style"] = "filled"
                 kw["fillcolor"] = cancel_color
             try:
-                kw["URL"] = f"file://{inspect.getfile(nx_node.fn)}"
+
+                filename = urlencode(inspect.getfile(nx_node.fn))
+
+                kw["URL"] = f"file://{filename}"
             except Exception as ex:
                 log.debug("Ignoring error while inspecting file of %s: %s", nx_node, ex)
 
@@ -362,7 +394,7 @@ def render_pydot(dot: pydot.Dot, filename=None, show=False, jupyter_render: str
     :param str filename:
         Write diagram into a file.
         Common extensions are ``.png .dot .jpg .jpeg .pdf .svg``
-        call :func:`plot.supported_plot_formats()` for more.
+        call :func:`.supported_plot_formats()` for more.
     :param show:
         If it evaluates to true, opens the  diagram in a  matplotlib window.
         If it equals `-1`, it returns the image but does not open the Window.
@@ -427,7 +459,7 @@ def legend(
     :param arch_url:
         the url to the architecture section explaining *graphtik* glossary.
 
-    See :func:`render_pydot` for the rest arguments.
+    See :func:`.render_pydot` for the rest arguments.
     """
 
     _monkey_patch_for_jupyter(pydot)
